@@ -1,3 +1,6 @@
+# Copyright © 2022 Intel Corporation
+#
+# SPDX-License-Identifier: MIT
 import copy
 import os
 import pytest
@@ -142,7 +145,7 @@ class TestXGBoostExperiment:
       ],
       budget=5,
     )
-    experiment = sigopt.create_experiment(**experiment_config)
+    experiment = sigopt.create_aiexperiment(**experiment_config)
     custom_run = experiment.create_run()
 
     ctx = sigopt.xgboost.run(
