@@ -2,6 +2,7 @@
 #
 # SPDX-License-Identifier: MIT
 import json
+import os
 import random
 import string
 
@@ -21,6 +22,10 @@ class JobRunnerService(Service):
   DEFAULT_EPHEMERAL_STORAGE_REQUEST = "128Mi"
   EXPERIMENT_ENV_KEY = "ORCHESTRATE_EXPERIMENT_ID"
 
+  @property
+  def controller_image(self):
+    return os.environ.get("SIGOPT_CONTROLLER_IMAGE", DEFAULT_CONTROLLER_IMAGE)
+
   def sigopt_env_vars(self, project_id):
     client, project = self.services.sigopt_service.ensure_project_exists(project_id)
     return format_k8s_env_vars({
@@ -142,20 +147,34 @@ class JobRunnerService(Service):
           },
           'spec': {
             'serviceAccount': 'controller',
+            'securityContext': {
+              'allowPrivilegeEscalation': False,
+              'readOnlyRootFilesystem': True,
+            },
             'restartPolicy': 'Never',
             'containers': [
               {
-                'image': DEFAULT_CONTROLLER_IMAGE,
+                'image': self.controller_image,
                 'imagePullPolicy': 'Always',
                 'name': 'controller',
                 'env': env_vars,
                 'args': run_command,
+                'resources': {
+                  'limits': {
+                    'cpu': '100m',
+                    'memory': '128Mi',
+                  },
+                },
                 'volumeMounts': [
                   {
                     'name': job_info_volume_name,
                     'mountPath': job_info_path,
                   },
                 ],
+                'securityContext': {
+                  'allowPrivilegeEscalation': False,
+                  'readOnlyRootFilesystem': True,
+                },
               },
             ],
             'volumes': [{
